@@ -9,10 +9,23 @@
  */
 angular.module('groongaAdminApp')
   .controller('TableSearchController', [
-    '$scope', '$routeParams', '$location', '$http', '$filter', 'schemaLoader',
-    function ($scope, $routeParams, $location, $http, $filter, schemaLoader) {
+    '$scope',
+    '$routeParams',
+    '$location',
+    '$http',
+    '$filter',
+    '$interval',
+    'schemaLoader',
+    function ($scope,
+              $routeParams,
+              $location,
+              $http,
+              $filter,
+              $interval,
+              schemaLoader) {
       var schema;
       var client = new GroongaClient($http);
+      var autoRefreshPromise = null;
 
       function findElement(array, finder) {
         var i, length;
@@ -58,12 +71,17 @@ angular.module('groongaAdminApp')
         }
         $scope.currentPage = computeCurrentPage($scope.parameters.offset || 0);
         $scope.maxNPages = 10;
+        $scope.autoRefreshIntervalInSeconds = 0;
 
         $scope.search = search;
         $scope.incrementalSearch = incrementalSearch;
-        $scope.clear  = clear;
+        $scope.updateAutoRefresh = updateAutoRefresh;
+        $scope.clearQuery = clearQuery;
+        $scope.clear = clear;
         $scope.toggleSort = toggleSort;
         $scope.selectDrilldown = selectDrilldown;
+        $scope.toggleAllColumns = toggleAllColumns;
+        $scope.toggleAllColumnsChecked = true;
       }
 
       function packColumns(columns) {
@@ -193,6 +211,23 @@ angular.module('groongaAdminApp')
         select(buildParameters());
       }
 
+      function updateAutoRefresh() {
+        if (autoRefreshPromise) {
+          $interval.cancel(autoRefreshPromise);
+          autoRefreshPromise = null;
+        }
+        if ($scope.autoRefreshIntervalInSeconds > 0) {
+          autoRefreshPromise =
+            $interval(incrementalSearch,
+                      $scope.autoRefreshIntervalInSeconds * 1000);
+        }
+      }
+
+      function clearQuery() {
+        $scope.parameters.query = '';
+        incrementalSearch();
+      }
+
       function clear() {
         $location.search({});
       }
@@ -211,6 +246,17 @@ angular.module('groongaAdminApp')
         }
       }
 
+      function toggleAllColumns() {
+        $scope.table.allColumns.forEach(function(columnInfo) {
+          if (columnInfo.name === '_id') {
+            columnInfo.output = true;
+          } else {
+            columnInfo.output = $scope.toggleAllColumnsChecked;
+          }
+        });
+        incrementalSearch();
+      }
+
       function toggleSort(column) {
         var columnInfo = findElement($scope.table.allColumns, function(columnInfo) {
           return columnInfo.name === column.name;
@@ -241,11 +287,6 @@ angular.module('groongaAdminApp')
         var column = findElement($scope.table.allColumns, function(column) {
           return column.name === key;
         });
-        if (column) {
-          if (column.valueType.isReferenceType) {
-            queryKey += '._key';
-          }
-        }
 
         var escapedValue;
         if (typeof value === 'string') {
@@ -296,7 +337,6 @@ angular.module('groongaAdminApp')
 
         return {
           name: name,
-          type: column.range,
           output: output,
           drilldown: drilldown,
           sort: sort,
@@ -306,7 +346,7 @@ angular.module('groongaAdminApp')
       }
 
       function addTimeColumn(columnInfo) {
-        if (columnInfo.type !== 'Time') {
+        if (columnInfo.valueType.name !== 'Time') {
           return;
         }
 
